abclinuxu.cz AbcLinuxu.cz itbiz.cz ITBiz.cz HDmag.cz HDmag.cz abcprace.cz AbcPráce.cz
AbcLinuxu hledá autory!
Inzerujte na AbcPráce.cz od 950 Kč
Rozšířené hledání
×

    dnes 00:33 | Nová verze

    Byla vydána OpenIndiana 2026.10. Unixový operační systém OpenIndiana (Wikipedie) vychází z OpenSolarisu (Wikipedie).

    Ladislav Hagara | Komentářů: 1
    dnes 00:22 | IT novinky

    Americký výrobce polovodičů onsemi (ON Semiconductor) zrušil plány na rozšíření výroby v rožnovském závodě v Česku za dvě miliardy dolarů (podle aktuálního kurzu zhruba 43,5 mld. Kč). Důvodem je vývoj na trhu.

    Ladislav Hagara | Komentářů: 1
    včera 13:00 | Bezpečnostní upozornění
    Nové vydání zlib opravuje několik problémů při kompresi a dekompresi dat, přetečení bufferů, čtení mimo vyhrazenou paměť, únik neinicializovaných dat. Zvlášť významné jsou chyby v inflateGetDictionary(), inflateSync() a gzwrite(), které mohou způsobit poškození paměti. Vysoká relevance - zlib používá řada systémových i aplikačních komponent.
    vencour | Komentářů: 1
    včera 12:25 | Bezpečnostní upozornění
    Digicert hlásí neoprávněné čtení archivních zákaznických údajů. Došlo k němu po migraci z února 2025, po níž se interní systém, dříve dostupný jen přes VPN, stal přístupným z internetu. Chyba v oprávněních umožnila nově vytvořeným účtům číst archivní záznamy. K přístupu k datům mělo dojít mezi 27. červnem a 2. červencem 2026. DigiCert neoprávněné čtení potvrdil až 19. října 2026. Problém zpočátku vyhodnotil jako tvorbu účtů, ne jako … více »
    vencour | Komentářů: 1
    včera 04:44 | Pozvánky

    O víkendu probíhá na FIT VUT v Brně konference OpenAlt 2026 o otevřeném softwaru a datech, IT bezpečnosti, DIY a IoT. Na programu je spousta zajímavých přednášek. Pokud jste v Brně, stavte se. Vstup zdarma. Přednášky lze sledovat i online na VHSky a YouTube.

    Ladislav Hagara | Komentářů: 1
    včera 02:11 | IT novinky

    Qualcomm uzavřel víceletou dohodu se SpaceX. Bude dodávat rádiové technologie, baseband jednotky a software pro plánovanou pozemní 5G síť Starlink Mobile. Výstavba má zahrnovat desítky tisíc základnových stanic v USA. Zahájení nasazování se očekává v roce 2027. Qualcomm dohodu označuje za svůj dosud největší 5G kontrakt.

    vencour | Komentářů: 0
    včera 02:00 | IT novinky

    Google rozšířil Cloud Vulnerability Reward Program. Nově nabízí odměnu až 250 tisíc dolarů za vysoce závažné architektonické bezpečnostní chyby označované jako Root-in-Cloud.

    vencour | Komentářů: 0
    6.11. 12:22 | IT novinky

    V březnu byla oznámena spolupráce GrapheneOS s Motorolou. Nejnovější vlajka Motorola Signature 27 je první Motorola s oficiální podporou GrapheneOS. GrapheneOS (Wikpedie) je varianta Androidu zaměřující se na bezpečnost a soukromí.

    Ladislav Hagara | Komentářů: 0
    6.11. 04:55 | Nová verze

    Omarchy (Wikipedie) je linuxová distribuce s dlaždicovým správcem oken Hyprland. Založena je na Arch Linuxu. Vydána byla v nové verzi 4.5.0. Nově také pro Apple Silicon, konkrétně pro M1/M2/M3/Neo MacBooky.

    Ladislav Hagara | Komentářů: 3
    6.11. 03:22 | Nová verze

    Byla vydána nová stabilní verze 8.3 webového prohlížeče Vivaldi (Wikipedie). Postavena je na Chromiu 156 s bezpečnostními opravami z Chromia 157. Přehled novinek i s náhledy v příspěvku na blogu.

    Ladislav Hagara | Komentářů: 0
    Které desktopové prostředí na Linuxu používáte?
     (9%)
     (7%)
     (4%)
     (21%)
     (30%)
     (9%)
     (5%)
     (2%)
     (14%)
     (20%)
    Celkem 3003 hlasů
     Komentářů: 35, poslední 6.11. 23:27
    Rozcestník

    Dotaz: SunRay na Linuxu

    9.11.2008 20:06 jnovacek | skóre: 22 | blog: NovLin
    SunRay na Linuxu
    Přečteno: 491×
    Již delší dobu se snažím rozběhat SunRay systém na openSUSE. SunRay je speciální bezdisková stanice. Na openSUSE funguje postup instalace https://wiki.sun-rays.org/index.php/Sun_Ray_Server_Software_4.0_on_openSUSE_10.3. Nepovedlo se mi, ale zprovoznit vše. Hlavně nefunguje USB. Bez USB pro nás tento systém ztrácí význam. Použít Solaris nemohu. Při instalaci jsem dostal následující výstup
    ...
    +++ Making and installing Sun Ray Audio module ...

    rm -rf .tmp_versions *.cmd *.ko *.o *.mod.c .*.cmd
    make -C /lib/modules/2.6.22.5-31-default/build SUBDIRS=/usr/src/SUNWut/utadem modules
    make[1]: Entering directory `/usr/src/linux-2.6.22.5-31-obj/i386/default'
    make -C ../../../linux-2.6.22.5-31 O=../linux-2.6.22.5-31-obj/i386/default modules
    CC [M] /usr/src/SUNWut/utadem/utadem.o
    /usr/src/SUNWut/utadem/utadem.c:14:26: error: linux/config.h: No such file or directory
    make[4]: *** [/usr/src/SUNWut/utadem/utadem.o] Error 1
    make[3]: *** [_module_/usr/src/SUNWut/utadem] Error 2
    make[2]: *** [modules] Error 2
    make[1]: *** [modules] Error 2
    make[1]: Leaving directory `/usr/src/linux-2.6.22.5-31-obj/i386/default'
    make: *** [default] Error 2

    +++ Done.

    +++ SUNWutio-4.0-48.i386.rpm

    +++ Making and installing Sun Ray UTIO module ...

    rm -rf .tmp_versions *.cmd *.ko *.o *.mod.c .*.cmd
    make -C /lib/modules/2.6.22.5-31-default/build SUBDIRS=/usr/src/SUNWut/utio modules
    make[1]: Entering directory `/usr/src/linux-2.6.22.5-31-obj/i386/default'
    make -C ../../../linux-2.6.22.5-31 O=../linux-2.6.22.5-31-obj/i386/default modules
    CC [M] /usr/src/SUNWut/utio/utio.o
    /usr/src/SUNWut/utio/utio.c:12:26: error: linux/config.h: No such file or directory
    make[4]: *** [/usr/src/SUNWut/utio/utio.o] Error 1
    make[3]: *** [_module_/usr/src/SUNWut/utio] Error 2
    make[2]: *** [modules] Error 2
    make[1]: *** [modules] Error 2
    make[1]: Leaving directory `/usr/src/linux-2.6.22.5-31-obj/i386/default'
    make: *** [default] Error 2

    +++ Done.

    +++ SUNWutdsk-4.0-48.i386.rpm

    +++ Making and installing Sun Ray Mass Storage modules ...

    rm -rf .tmp_versions *.cmd *.ko *.o *.mod.c .*.cmd
    make -C /lib/modules/2.6.22.5-31-default/build SUBDIRS=/usr/src/SUNWut/utdisk modules
    make[1]: Entering directory `/usr/src/linux-2.6.22.5-31-obj/i386/default'
    make -C ../../../linux-2.6.22.5-31 O=../linux-2.6.22.5-31-obj/i386/default modules
    CC [M] /usr/src/SUNWut/utdisk/utdisk.o
    CC [M] /usr/src/SUNWut/utdisk/utdiskctl.o
    Building modules, stage 2.
    MODPOST 2 modules
    CC /usr/src/SUNWut/utdisk/utdisk.mod.o
    LD [M] /usr/src/SUNWut/utdisk/utdisk.ko
    CC /usr/src/SUNWut/utdisk/utdiskctl.mod.o
    LD [M] /usr/src/SUNWut/utdisk/utdiskctl.ko
    make[1]: Leaving directory `/usr/src/linux-2.6.22.5-31-obj/i386/default'
    install -d /lib/modules/2.6.22.5-31-default/misc
    install -c utdisk.ko utdiskctl.ko /lib/modules/2.6.22.5-31-default/misc

    +++ Done.
    ...
    To co nefunguje je pravděpodobně linux/config.h Dokážete mi někdo poradit co mám udělat, aby se kompilace povedla?
    Předem děkuji

    Odpovědi

    9.11.2008 23:08 Zdeněk Burda | skóre: 61 | blog: Zdendův blog | Praha
    Rozbalit Rozbalit vše Re: SunRay na Linuxu
    Google neporadil? :-)

    Nejrychlejší řešení - uděla ln -s autoconf.h config.h (v 2.6.19 jádře tuším zrušili config.h a místo něj se teď používá autoconf.h). Další možností je upravit zdrojáky tak aby nevyžadovaly config.h, ale autoconf.h. Když tohle projde, tak můžeš jen doufat, že to byla jediná věc která není s aktuálním jádrem kompatibilní.

    Proč nelze použít Solaris? Tam tyhle věci nemusíš řešit. V dřívějších verzích SunRay serveru prý v Linuxu některé věci prostě nechodily a jediným řešením pro 100% funkčnost terminálů byl Solaris, ale třeba se to v poslední verzi změnilo.
    -- Nezdar není hanbou, hanbou je strach z pokusu.

    Založit nové vlákno • Nahoru

    Tiskni Sdílej: Linkuj Jaggni to Vybrali.sme.sk Google Del.icio.us Facebook

    ISSN 1214-1267   www.czech-server.cz
    © 1999-2015 Nitemedia s. r. o. Všechna práva vyhrazena.